#WWSHC
This is an unofficial module to control WWS (https://wwschool.de; Also other Services using WebWeaver Software) via python code.

###Changes in 0.0.9:
* Added eventsystem (wws.events)
* Updated selenium to 4.1.0
* Started updating syntax of selenium find_element functions
* Corrected some IDs that have changed in WWS

###Example:
To see code examples, visit wwshc.jojojux.de/examples/


Requires: selenium>=3.141.0, win10toast>=0.9, pydatfile>=0.0.3
